summaryrefslogtreecommitdiff
path: root/ace/Message_Queue_T.h
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>2002-06-04 12:01:20 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>2002-06-04 12:01:20 +0000
commit61bdc9878439781b1b4f951604c56591e00f07f9 (patch)
treeb11c376e24d1e523dc40f3bf39440beac077d8f6 /ace/Message_Queue_T.h
parente260876ed8d6c86ba019387aa6cceb6ab5a2676b (diff)
downloadATCD-61bdc9878439781b1b4f951604c56591e00f07f9.tar.gz
ChangeLogTag:Tue Jun 4 06:46:27 2002 Douglas C. Schmidt <schmidt@tango.doc.wustl.edu>
Diffstat (limited to 'ace/Message_Queue_T.h')
-rw-r--r--ace/Message_Queue_T.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/ace/Message_Queue_T.h b/ace/Message_Queue_T.h
index 98dceb9a486..0c423c18541 100644
--- a/ace/Message_Queue_T.h
+++ b/ace/Message_Queue_T.h
@@ -305,16 +305,15 @@ public:
// = Activation control methods.
/**
- * Notifies all waiting threads that the queue has been deactivated
- * so they can wakeup and continue other processing. If <pulse> is
- * 0 then the queue's state is changed to deactivated and any other
- * operations called until the queue is activated again will
- * immediately return -1 with <errno> == ESHUTDOWN. If <pulse> is
+ * Notify all waiting threads so they can wakeup and continue other
+ * processing. If <pulse> is 0 the queue's state is changed to
+ * deactivated and other operations called until the queue is
+ * activated again will return -1 with <errno> == ESHUTDOWN. If <pulse> is
* non-0 then only the waiting threads are notified and the queue's state
* is not changed. In either case, however, no messages are removed
* from the queue. Returns WAS_INACTIVE if queue was inactive before
* the call and WAS_ACTIVE if queue was active before the call. */
- virtual int deactivate (void);
+ virtual int deactivate (int pulse = 0);
/**
* Reactivate the queue so that threads can enqueue and dequeue
@@ -1127,14 +1126,15 @@ public:
// = Activation control methods.
/**
- * Deactivate the queue and wakeup all threads waiting on the queue
- * so they can continue. No messages are removed from the queue,
- * however. Any other operations called until the queue is
- * activated again will immediately return -1 with <errno> ==
- * ESHUTDOWN. Returns WAS_INACTIVE if queue was inactive before the
- * call and WAS_ACTIVE if queue was active before the call.
- */
- virtual int deactivate (void);
+ * Notify all waiting threads so they can wakeup and continue other
+ * processing. If <pulse> is 0 the queue's state is changed to
+ * deactivated and other operations called until the queue is
+ * activated again will return -1 with <errno> == ESHUTDOWN. If <pulse> is
+ * non-0 then only the waiting threads are notified and the queue's state
+ * is not changed. In either case, however, no messages are removed
+ * from the queue. Returns WAS_INACTIVE if queue was inactive before
+ * the call and WAS_ACTIVE if queue was active before the call. */
+ virtual int deactivate (int pulse);
/**
* Reactivate the queue so that threads can enqueue and dequeue